Clutter detection module
========================

.. toctree::
   :maxdepth: 1

   ../jupyter_notebooks/clutter_detection.ipynb
   Fuzzy Echo Classification (wradlib) <https://docs.wradlib.org/en/stable/notebooks/classify/wradlib_fuzzy_echo_classify.html>